==> aibasics-0.2.1.tar.gz: aibasics-0.2.1/README.md <==
# AI Uncovered

[![pypi-image]][pypi-url]
[![license-image]][license-url]
[![version-image]][release-url]
[![release-date-image]][release-url]
[![jupyter-book-image]][docs-url]

<!-- Links: -->
[pypi-image]: https://img.shields.io/pypi/v/aibasics
[license-image]: https://img.shields.io/github/license/chu-aie/aibasics
[license-url]: https://github.com/chu-aie/aibasics/blob/main/LICENSE
[version-image]: https://img.shields.io/github/v/release/chu-aie/aibasics?sort=semver
[release-date-image]: https://img.shields.io/github/release-date/chu-aie/aibasics
[release-url]: https://github.com/chu-aie/aibasics/releases
[jupyter-book-image]: https://jupyterbook.org/en/stable/_images/badge.svg

[repo-url]: https://github.com/chu-aie/aibasics
[pypi-url]: https://pypi.org/project/aibasics
[docs-url]: https://chu-aie.github.io/aibasics
[changelog]: https://github.com/chu-aie/aibasics/blob/main/CHANGELOG.md
[contributing guidelines]: https://github.com/chu-aie/aibasics/blob/main/CONTRIBUTING.md
<!-- Links: -->

AI Uncovered: A Comprehensive Guide to AI Basics and Applications

- Documentation: [https://chu-aie.github.io/aibasics][docs-url]
- GitHub: [https://github.com/chu-aie/aibasics][repo-url]
- PyPI: [https://pypi.org/project/aibasics][pypi-url]

AI Uncovered is a 15-week, beginner-friendly course in Korean, designed to provide a comprehensive introduction to artificial intelligence (AI) and its real-world applications. Students will explore various AI concepts and techniques, such as machine learning, deep learning, natural language processing, and object detection. The course includes hands-on lab sessions using Google Colab, allowing students to practice what they've learned. By the end, students will have a solid understanding of AI fundamentals and be prepared for an AI-driven future.

## Changelog

See the [CHANGELOG] for more information.

## Contributing

Contributions are welcome! Please see the [contributing guidelines] for more information.

## License

This project is released under the [CC-BY-4.0 License][license-url].

==> aibasics-0.2.2.tar.gz: aibasics-0.2.2/README.md <==
# AI Uncovered

[![pypi-image]][pypi-url]
[![license-image]][license-url]
[![version-image]][release-url]
[![release-date-image]][release-url]
[![jupyter-book-image]][docs-url]

<!-- Links: -->
[pypi-image]: https://img.shields.io/pypi/v/aibasics
[license-image]: https://img.shields.io/github/license/chu-aie/aibasics
[license-url]: https://github.com/chu-aie/aibasics/blob/main/LICENSE
[version-image]: https://img.shields.io/github/v/release/chu-aie/aibasics?sort=semver
[release-date-image]: https://img.shields.io/github/release-date/chu-aie/aibasics
[release-url]: https://github.com/chu-aie/aibasics/releases
[jupyter-book-image]: https://jupyterbook.org/en/stable/_images/badge.svg

[repo-url]: https://github.com/chu-aie/aibasics
[pypi-url]: https://pypi.org/project/aibasics
[docs-url]: https://aibasics.entelecheia.ai
[changelog]: https://github.com/chu-aie/aibasics/blob/main/CHANGELOG.md
[contributing guidelines]: https://github.com/chu-aie/aibasics/blob/main/CONTRIBUTING.md
<!-- Links: -->

AI Uncovered: A Comprehensive Guide to AI Basics and Applications

- Documentation: [https://aibasics.entelecheia.ai][docs-url]
- GitHub: [https://github.com/chu-aie/aibasics][repo-url]
- PyPI: [https://pypi.org/project/aibasics][pypi-url]

AI Uncovered is a 15-week, beginner-friendly course in Korean, designed to provide a comprehensive introduction to artificial intelligence (AI) and its real-world applications. Students will explore various AI concepts and techniques, such as machine learning, deep learning, natural language processing, and object detection. The course includes hands-on lab sessions using Google Colab, allowing students to practice what they've learned. By the end, students will have a solid understanding of AI fundamentals and be prepared for an AI-driven future.

## Changelog

See the [CHANGELOG] for more information.

## Contributing

Contributions are welcome! Please see the [contributing guidelines] for more information.

## License

This project is released under the [CC-BY-4.0 License][license-url].
